@@ -21,19 +21,25 @@ package org.apache.maven.plugin.surefire;
 
 import java.io.File;
 import java.lang.reflect.Constructor;
+
+import org.apache.maven.plugin.surefire.log.api.ConsoleLogger;
 import org.apache.maven.plugin.surefire.report.DefaultReporterFactory;
-import org.apache.maven.surefire.util.ReflectionUtils;
+import org.apache.maven.surefire.booter.SurefireReflector;
 import org.apache.maven.surefire.util.SurefireReflectionException;
 
 import javax.annotation.Nonnull;
 
+import static org.apache.maven.surefire.util.ReflectionUtils.getConstructor;
+import static org.apache.maven.surefire.util.ReflectionUtils.instantiateObject;
+import static org.apache.maven.surefire.util.ReflectionUtils.newInstance;
+
 /**
  * @author Kristian Rosenvold
  */
 public class CommonReflector
 {
     private final Class<?> startupReportConfiguration;
-
+    private final Class<?> consoleLogger;
     private final ClassLoader surefireClassLoader;
 
     public CommonReflector( @Nonnull ClassLoader surefireClassLoader )
@@ -43,6 +49,7 @@ public class CommonReflector
         try
         {
             startupReportConfiguration = surefireClassLoader.loadClass( StartupReportConfiguration.class.getName() );
+            consoleLogger = surefireClassLoader.loadClass( ConsoleLogger.class.getName() );
         }
         catch ( ClassNotFoundException e )
         {
@@ -50,31 +57,30 @@ public class CommonReflector
         }
     }
 
-    public Object createReportingReporterFactory( @Nonnull StartupReportConfiguration startupReportConfiguration )
+    public Object createReportingReporterFactory( @Nonnull StartupReportConfiguration startupReportConfiguration,
+                                                  @Nonnull ConsoleLogger consoleLogger )
     {
-        Class<?>[] args = new Class[]{ this.startupReportConfiguration };
+        Class<?>[] args = { this.startupReportConfiguration, this.consoleLogger };
         Object src = createStartupReportConfiguration( startupReportConfiguration );
-        Object[] params = new Object[]{ src };
-        return ReflectionUtils.instantiateObject( DefaultReporterFactory.class.getName(), args, params,
-                                                  surefireClassLoader );
+        Object logger = SurefireReflector.createConsoleLogger( consoleLogger, surefireClassLoader );
+        Object[] params = { src, logger };
+        return instantiateObject( DefaultReporterFactory.class.getName(), args, params, surefireClassLoader );
     }
 
-
-    Object createStartupReportConfiguration( @Nonnull StartupReportConfiguration reporterConfiguration )
+    private Object createStartupReportConfiguration( @Nonnull StartupReportConfiguration reporterConfiguration )
     {
-        Constructor<?> constructor = ReflectionUtils.getConstructor( startupReportConfiguration,
-                                                                     boolean.class, boolean.class,
-                                                                     String.class, boolean.class, boolean.class,
-                                                                     File.class, boolean.class, String.class,
-                                                                     String.class, boolean.class, int.class );
+        Constructor<?> constructor = getConstructor( startupReportConfiguration, boolean.class, boolean.class,
+                                                           String.class, boolean.class, boolean.class, File.class,
+                                                           boolean.class, String.class, File.class, boolean.class,
+                                                           int.class, String.class );
         //noinspection BooleanConstructorCall
         Object[] params = { reporterConfiguration.isUseFile(), reporterConfiguration.isPrintSummary(),
             reporterConfiguration.getReportFormat(), reporterConfiguration.isRedirectTestOutputToFile(),
             reporterConfiguration.isDisableXmlReport(), reporterConfiguration.getReportsDirectory(),
             reporterConfiguration.isTrimStackTrace(), reporterConfiguration.getReportNameSuffix(),
-            reporterConfiguration.getConfigurationHash(), reporterConfiguration.isRequiresRunHistory(),
-            reporterConfiguration.getRerunFailingTestsCount() };
-        return ReflectionUtils.newInstance( constructor, params );
+            reporterConfiguration.getStatisticsFile(), reporterConfiguration.isRequiresRunHistory(),
+            reporterConfiguration.getRerunFailingTestsCount(), reporterConfiguration.getXsdSchemaLocation() };
+        return newInstance( constructor, params );
     }
 
 }
