@@ -47,7 +47,7 @@ public class SurefireProperties
     implements KeyValueSource
 {
     private static final Collection<String> KEYS_THAT_CANNOT_BE_USED_AS_SYSTEM_PROPERTIES =
-            asList( "java.library.path", "file.encoding", "jdk.map.althashing.threshold" );
+            asList( "java.library.path", "file.encoding", "jdk.map.althashing.threshold", "line.separator" );
 
     private final LinkedHashSet<Object> items = new LinkedHashSet<Object>();
 
@@ -92,6 +92,7 @@ public class SurefireProperties
         super.clear();
     }
 
+    @Override
     public synchronized Enumeration<Object> keys()
     {
         return Collections.enumeration( items );
@@ -146,7 +147,6 @@ public class SurefireProperties
 
         result.copyPropertiesFrom( props );
 
-        copyProperties( result, systemPropertyVariables );
         copyProperties( result, systemPropertyVariables );
 
         // We used to take all of our system properties and dump them in with the
@@ -170,6 +170,7 @@ public class SurefireProperties
         }
     }
 
+    @Override
     public void copyTo( Map<Object, Object> target )
     {
         target.putAll( this );
@@ -191,6 +192,14 @@ public class SurefireProperties
         }
     }
 
+    public void setProperty( String key, Long value )
+    {
+        if ( value != null )
+        {
+            setProperty( key, value.toString() );
+        }
+    }
+
     public void addList( List<?> items, String propertyPrefix )
     {
         if ( items != null && !items.isEmpty() )
