@@ -27,22 +27,27 @@ import org.apache.maven.surefire.report.ConsoleOutputReceiver;
 import org.apache.maven.surefire.report.ReportEntry;
 import org.apache.maven.surefire.report.RunListener;
 import org.apache.maven.surefire.report.StackTraceWriter;
+import org.apache.maven.surefire.report.TestSetReportEntry;
 
 import java.io.BufferedReader;
 import java.io.File;
 import java.io.IOException;
 import java.io.StringReader;
 import java.nio.ByteBuffer;
-import java.util.Properties;
+import java.util.Collections;
+import java.util.Map;
 import java.util.Queue;
 import java.util.Set;
 import java.util.StringTokenizer;
 import java.util.TreeSet;
+import java.util.concurrent.ConcurrentHashMap;
 import java.util.concurrent.ConcurrentLinkedQueue;
+import java.util.concurrent.atomic.AtomicBoolean;
 import java.util.concurrent.atomic.AtomicLong;
 
 import static java.lang.Integer.decode;
 import static java.lang.System.currentTimeMillis;
+import static java.util.Collections.unmodifiableMap;
 import static org.apache.maven.surefire.booter.ForkingRunListener.BOOTERCODE_BYE;
 import static org.apache.maven.surefire.booter.ForkingRunListener.BOOTERCODE_CONSOLE;
 import static org.apache.maven.surefire.booter.ForkingRunListener.BOOTERCODE_DEBUG;
@@ -83,38 +88,49 @@ public class ForkClient
 
     private final DefaultReporterFactory defaultReporterFactory;
 
-    private final Properties testVmSystemProperties;
+    private final Map<String, String> testVmSystemProperties = new ConcurrentHashMap<String, String>();
 
     private final NotifiableTestStream notifiableTestStream;
 
     private final Queue<String> testsInProgress = new ConcurrentLinkedQueue<String>();
 
     /**
-     * <t>testSetStartedAt</t> is set to non-zero after received
+     * {@code testSetStartedAt} is set to non-zero after received
      * {@link org.apache.maven.surefire.booter.ForkingRunListener#BOOTERCODE_TESTSET_STARTING test-set}.
      */
     private final AtomicLong testSetStartedAt = new AtomicLong( START_TIME_ZERO );
 
     private final ConsoleLogger log;
 
+    private final boolean debug;
+
+    /**
+     * prevents from printing same warning
+     */
+    private final AtomicBoolean printedErrorStream;
+
+    /**
+     * Used by single Thread started by {@link ThreadedStreamConsumer} and therefore does not need to be volatile.
+     */
     private RunListener testSetReporter;
 
+    /**
+     * Written by one Thread and read by another: Main Thread and ForkStarter's Thread.
+     */
     private volatile boolean saidGoodBye;
 
     private volatile StackTraceWriter errorInFork;
 
     private volatile int forkNumber;
 
-    // prevents from printing same warning
-    private boolean printedErrorStream;
-
-    public ForkClient( DefaultReporterFactory defaultReporterFactory, Properties testVmSystemProperties,
-                       NotifiableTestStream notifiableTestStream, ConsoleLogger log )
+    public ForkClient( DefaultReporterFactory defaultReporterFactory, NotifiableTestStream notifiableTestStream,
+                       ConsoleLogger log, boolean debug, AtomicBoolean printedErrorStream )
     {
         this.defaultReporterFactory = defaultReporterFactory;
-        this.testVmSystemProperties = testVmSystemProperties;
         this.notifiableTestStream = notifiableTestStream;
         this.log = log;
+        this.debug = debug;
+        this.printedErrorStream = printedErrorStream;
     }
 
     protected void stopOnNextTest()
@@ -131,6 +147,10 @@ public class ForkClient
 
     /**
      * Called in concurrent Thread.
+     * Will shutdown if timeout was reached.
+     *
+     * @param currentTimeMillis    current time in millis seconds
+     * @param forkedProcessTimeoutInSeconds timeout in seconds given by MOJO
      */
     public final void tryToTimeout( long currentTimeMillis, int forkedProcessTimeoutInSeconds )
     {
@@ -151,6 +171,7 @@ public class ForkClient
         return defaultReporterFactory;
     }
 
+    @Override
     public final void consumeLine( String s )
     {
         if ( isNotBlank( s ) )
@@ -205,7 +226,7 @@ public class ForkClient
             case BOOTERCODE_TESTSET_COMPLETED:
                 testsInProgress.clear();
 
-                getTestSetReporter().testSetCompleted( createReportEntry( remaining ) );
+                getTestSetReporter().testSetCompleted( createReportEntry( remaining, testVmSystemProperties ) );
                 break;
             case BOOTERCODE_TEST_STARTING:
                 ReportEntry reportEntry = createReportEntry( remaining );
@@ -249,10 +270,7 @@ public class ForkClient
                 StringBuilder value = new StringBuilder();
                 unescapeString( key, remaining.substring( 0, keyEnd ) );
                 unescapeString( value, remaining.substring( keyEnd + 1 ) );
-                synchronized ( testVmSystemProperties )
-                {
-                    testVmSystemProperties.put( key.toString(), value.toString() );
-                }
+                testVmSystemProperties.put( key.toString(), value.toString() );
                 break;
             case BOOTERCODE_STDOUT:
                 writeTestOutput( remaining, true );
@@ -299,18 +317,27 @@ public class ForkClient
     {
         if ( event == null || !event.contains( PRINTABLE_JVM_NATIVE_STREAM ) )
         {
-            final String msg = "Corrupted stdin stream in forked JVM " + forkNumber + ".";
-            final InPluginProcessDumpSingleton util = InPluginProcessDumpSingleton.getSingleton();
-            final File dump =
+            String msg = "Corrupted STDOUT by directly writing to native stream in forked JVM " + forkNumber + ".";
+
+            InPluginProcessDumpSingleton util = InPluginProcessDumpSingleton.getSingleton();
+            File dump =
                     e == null
                     ? util.dumpText( msg + " Stream '" + event + "'.", defaultReporterFactory, forkNumber )
                     : util.dumpException( e, msg + " Stream '" + event + "'.", defaultReporterFactory, forkNumber );
 
-            if ( !printedErrorStream )
+            if ( printedErrorStream.compareAndSet( false, true ) )
             {
-                printedErrorStream = true;
-                log.warning( msg + " See the dump file " + dump.getAbsolutePath() );
+                log.warning( msg + " See FAQ web page and the dump file " + dump.getAbsolutePath() );
             }
+
+            if ( debug && event != null )
+            {
+                log.debug( event );
+            }
+        }
+        else if ( debug )
+        {
+            log.debug( event );
         }
         else
         {
@@ -355,7 +382,12 @@ public class ForkClient
         return unescape( remaining );
     }
 
-    private ReportEntry createReportEntry( String untokenized )
+    private TestSetReportEntry createReportEntry( String untokenized )
+    {
+        return createReportEntry( untokenized, Collections.<String, String>emptyMap() );
+    }
+
+    private TestSetReportEntry createReportEntry( String untokenized, Map<String, String> systemProperties )
     {
         StringTokenizer tokens = new StringTokenizer( untokenized, "," );
         try
@@ -369,7 +401,7 @@ public class ForkClient
             final StackTraceWriter stackTraceWriter =
                     tokens.hasMoreTokens() ? deserializeStackTraceWriter( tokens ) : null;
 
-            return reportEntry( source, name, group, stackTraceWriter, elapsed, message );
+            return reportEntry( source, name, group, stackTraceWriter, elapsed, message, systemProperties );
         }
         catch ( RuntimeException e )
         {
@@ -398,6 +430,11 @@ public class ForkClient
         return stringBuffer.toString();
     }
 
+    public final Map<String, String> getTestVmSystemProperties()
+    {
+        return unmodifiableMap( testVmSystemProperties );
+    }
+
     /**
      * Used when getting reporters on the plugin side of a fork.
      * Used by testing purposes only. May not be volatile variable.
