@@ -21,41 +21,45 @@ package org.apache.maven.plugins.surefire.report;
 
 import java.io.File;
 import java.text.NumberFormat;
-import java.util.Iterator;
 import java.util.List;
 import java.util.Locale;
 import java.util.Map;
 import java.util.ResourceBundle;
-import java.util.StringTokenizer;
 import org.apache.maven.doxia.markup.HtmlMarkup;
 import org.apache.maven.doxia.sink.Sink;
 import org.apache.maven.doxia.sink.SinkEventAttributeSet;
 import org.apache.maven.doxia.sink.SinkEventAttributes;
+import org.apache.maven.doxia.util.DoxiaUtils;
+import org.apache.maven.plugin.surefire.log.api.ConsoleLogger;
 import org.apache.maven.reporting.MavenReportException;
 
+import static org.apache.maven.doxia.sink.Sink.JUSTIFY_LEFT;
+
 /**
  *
  */
-public class SurefireReportGenerator
+public final class SurefireReportGenerator
 {
-    private final SurefireReportParser report;
+    private static final int LEFT = JUSTIFY_LEFT;
 
-    private List<ReportTestSuite> testSuites;
+    private static final Object[] TAG_TYPE_START = { HtmlMarkup.TAG_TYPE_START };
+
+    private static final Object[] TAG_TYPE_END = { HtmlMarkup.TAG_TYPE_END };
+
+    private final SurefireReportParser report;
 
     private final boolean showSuccess;
 
     private final String xrefLocation;
 
-    private static final int LEFT = Sink.JUSTIFY_LEFT;
+    private List<ReportTestSuite> testSuites;
 
     public SurefireReportGenerator( List<File> reportsDirectories, Locale locale, boolean showSuccess,
-                                    String xrefLocation )
+                                    String xrefLocation, ConsoleLogger consoleLogger )
     {
-        report = new SurefireReportParser( reportsDirectories, locale );
-
-        this.xrefLocation = xrefLocation;
-
+        report = new SurefireReportParser( reportsDirectories, locale, consoleLogger );
         this.showSuccess = showSuccess;
+        this.xrefLocation = xrefLocation;
     }
 
     public void doGenerateReport( ResourceBundle bundle, Sink sink )
@@ -307,52 +311,7 @@ public class SurefireReportGenerator
                 {
                     if ( showSuccess || suite.getNumberOfErrors() != 0 || suite.getNumberOfFailures() != 0 )
                     {
-
-                        sink.tableRow();
-
-                        sink.tableCell();
-
-                        sink.link( "#" + suite.getPackageName() + suite.getName() );
-
-                        if ( suite.getNumberOfErrors() > 0 )
-                        {
-                            sinkIcon( "error", sink );
-                        }
-                        else if ( suite.getNumberOfFailures() > 0 )
-                        {
-                            sinkIcon( "junit.framework", sink );
-                        }
-                        else if ( suite.getNumberOfSkipped() > 0 )
-                        {
-                            sinkIcon( "skipped", sink );
-                        }
-                        else
-                        {
-                            sinkIcon( "success", sink );
-                        }
-
-                        sink.link_();
-
-                        sink.tableCell_();
-
-                        sinkCellLink( sink, suite.getName(), "#" + suite.getPackageName() + suite.getName() );
-
-                        sinkCell( sink, Integer.toString( suite.getNumberOfTests() ) );
-
-                        sinkCell( sink, Integer.toString( suite.getNumberOfErrors() ) );
-
-                        sinkCell( sink, Integer.toString( suite.getNumberOfFailures() ) );
-
-                        sinkCell( sink, Integer.toString( suite.getNumberOfSkipped() ) );
-
-                        String percentage =
-                            report.computePercentage( suite.getNumberOfTests(), suite.getNumberOfErrors(),
-                                                      suite.getNumberOfFailures(), suite.getNumberOfSkipped() );
-                        sinkCell( sink, percentage + "%" );
-
-                        sinkCell( sink, numberFormat.format( suite.getTimeElapsed() ) );
-
-                        sink.tableRow_();
+                        constructTestSuiteSection( sink, numberFormat, suite );
                     }
                 }
 
@@ -369,6 +328,54 @@ public class SurefireReportGenerator
         sink.section1_();
     }
 
+    private void constructTestSuiteSection( Sink sink, NumberFormat numberFormat, ReportTestSuite suite )
+    {
+        sink.tableRow();
+
+        sink.tableCell();
+
+        sink.link( "#" + suite.getPackageName() + suite.getName() );
+
+        if ( suite.getNumberOfErrors() > 0 )
+        {
+            sinkIcon( "error", sink );
+        }
+        else if ( suite.getNumberOfFailures() > 0 )
+        {
+            sinkIcon( "junit.framework", sink );
+        }
+        else if ( suite.getNumberOfSkipped() > 0 )
+        {
+            sinkIcon( "skipped", sink );
+        }
+        else
+        {
+            sinkIcon( "success", sink );
+        }
+
+        sink.link_();
+
+        sink.tableCell_();
+
+        sinkCellLink( sink, suite.getName(), "#" + suite.getPackageName() + suite.getName() );
+
+        sinkCell( sink, Integer.toString( suite.getNumberOfTests() ) );
+
+        sinkCell( sink, Integer.toString( suite.getNumberOfErrors() ) );
+
+        sinkCell( sink, Integer.toString( suite.getNumberOfFailures() ) );
+
+        sinkCell( sink, Integer.toString( suite.getNumberOfSkipped() ) );
+
+        String percentage = report.computePercentage( suite.getNumberOfTests(), suite.getNumberOfErrors(),
+                                                      suite.getNumberOfFailures(), suite.getNumberOfSkipped() );
+        sinkCell( sink, percentage + "%" );
+
+        sinkCell( sink, numberFormat.format( suite.getTimeElapsed() ) );
+
+        sink.tableRow_();
+    }
+
     private void constructTestCasesSection( ResourceBundle bundle, Sink sink )
     {
         NumberFormat numberFormat = report.getNumberFormat();
@@ -399,7 +406,7 @@ public class SurefireReportGenerator
 
                 for ( ReportTestCase testCase : testCases )
                 {
-                    if ( testCase.getFailure() != null || showSuccess )
+                    if ( testCase.hasFailure() || showSuccess )
                     {
                         showTable = true;
 
@@ -415,111 +422,9 @@ public class SurefireReportGenerator
 
                     for ( ReportTestCase testCase : testCases )
                     {
-                        if ( testCase.getFailure() != null || showSuccess )
+                        if ( testCase.hasFailure() || showSuccess )
                         {
-                            sink.tableRow();
-
-                            sink.tableCell();
-
-                            Map<String, Object> failure = testCase.getFailure();
-
-                            if ( failure != null )
-                            {
-                                sink.link( "#" + testCase.getFullName() );
-
-                                sinkIcon( (String) failure.get( "type" ), sink );
-
-                                sink.link_();
-                            }
-                            else
-                            {
-                                sinkIcon( "success", sink );
-                            }
-
-                            sink.tableCell_();
-
-                            if ( failure != null )
-                            {
-                                sink.tableCell();
-
-                                sinkLink( sink, testCase.getName(), "#" + testCase.getFullName() );
-
-                                SinkEventAttributeSet atts = new SinkEventAttributeSet();
-                                atts.addAttribute( SinkEventAttributes.CLASS, "detailToggle" );
-                                atts.addAttribute( SinkEventAttributes.STYLE, "display:inline" );
-                                sink.unknown( "div", new Object[]{ HtmlMarkup.TAG_TYPE_START }, atts );
-
-                                sink.link( "javascript:toggleDisplay('" + toHtmlId( testCase.getFullName() ) + "');" );
-
-                                atts = new SinkEventAttributeSet();
-                                atts.addAttribute( SinkEventAttributes.STYLE, "display:inline;" );
-                                atts.addAttribute( SinkEventAttributes.ID, toHtmlId( testCase.getFullName() ) + "off" );
-                                sink.unknown( "span", new Object[]{ HtmlMarkup.TAG_TYPE_START }, atts );
-                                sink.text( " + " );
-                                sink.unknown( "span", new Object[]{ HtmlMarkup.TAG_TYPE_END }, null );
-
-                                atts = new SinkEventAttributeSet();
-                                atts.addAttribute( SinkEventAttributes.STYLE, "display:none;" );
-                                atts.addAttribute( SinkEventAttributes.ID, toHtmlId( testCase.getFullName() ) + "on" );
-                                sink.unknown( "span", new Object[]{ HtmlMarkup.TAG_TYPE_START }, atts );
-                                sink.text( " - " );
-                                sink.unknown( "span", new Object[]{ HtmlMarkup.TAG_TYPE_END }, null );
-
-                                sink.text( "[ Detail ]" );
-                                sink.link_();
-
-                                sink.unknown( "div", new Object[]{ HtmlMarkup.TAG_TYPE_END }, null );
-
-                                sink.tableCell_();
-                            }
-                            else
-                            {
-                                sinkCell( sink, testCase.getName() );
-                            }
-
-                            sinkCell( sink, numberFormat.format( testCase.getTime() ) );
-
-                            sink.tableRow_();
-
-                            if ( failure != null )
-                            {
-                                sink.tableRow();
-
-                                sinkCell( sink, "" );
-                                sinkCell( sink, (String) failure.get( "message" ) );
-                                sinkCell( sink, "" );
-                                sink.tableRow_();
-
-                                List<String> detail = (List<String>) failure.get( "detail" );
-                                if ( detail != null )
-                                {
-
-                                    sink.tableRow();
-                                    sinkCell( sink, "" );
-
-                                    sink.tableCell();
-                                    SinkEventAttributeSet atts = new SinkEventAttributeSet();
-                                    atts.addAttribute( SinkEventAttributes.ID,
-                                                       toHtmlId( testCase.getFullName() ) + "error" );
-                                    atts.addAttribute( SinkEventAttributes.STYLE, "display:none;" );
-                                    sink.unknown( "div", new Object[]{ HtmlMarkup.TAG_TYPE_START }, atts );
-
-                                    sink.verbatim( null );
-                                    for ( String line : detail )
-                                    {
-                                        sink.text( line );
-                                        sink.lineBreak();
-                                    }
-                                    sink.verbatim_();
-
-                                    sink.unknown( "div", new Object[]{ HtmlMarkup.TAG_TYPE_END }, null );
-                                    sink.tableCell_();
-
-                                    sinkCell( sink, "" );
-
-                                    sink.tableRow_();
-                                }
-                            }
+                            constructTestCaseSection( sink, numberFormat, testCase );
                         }
                     }
 
@@ -537,150 +442,197 @@ public class SurefireReportGenerator
         sink.section1_();
     }
 
+    private void constructTestCaseSection( Sink sink, NumberFormat numberFormat, ReportTestCase testCase )
+    {
+        sink.tableRow();
+
+        sink.tableCell();
+
+        if ( testCase.getFailureType() != null )
+        {
+            sink.link( "#" + toHtmlId( testCase.getFullName() ) );
+
+            sinkIcon( testCase.getFailureType(), sink );
+
+            sink.link_();
+        }
+        else
+        {
+            sinkIcon( "success", sink );
+        }
+
+        sink.tableCell_();
+
+        if ( testCase.hasFailure() )
+        {
+            sink.tableCell();
+
+            sinkAnchor( sink, "TC_" + toHtmlId( testCase.getFullName() ) );
+
+            sinkLink( sink, testCase.getName(), "#" + toHtmlId( testCase.getFullName() ) );
+
+            SinkEventAttributeSet atts = new SinkEventAttributeSet();
+            atts.addAttribute( SinkEventAttributes.CLASS, "detailToggle" );
+            atts.addAttribute( SinkEventAttributes.STYLE, "display:inline" );
+            sink.unknown( "div", TAG_TYPE_START, atts );
+
+            sink.link( "javascript:toggleDisplay('" + toHtmlId( testCase.getFullName() ) + "');" );
+
+            atts = new SinkEventAttributeSet();
+            atts.addAttribute( SinkEventAttributes.STYLE, "display:inline;" );
+            atts.addAttribute( SinkEventAttributes.ID, toHtmlId( testCase.getFullName() ) + "off" );
+            sink.unknown( "span", TAG_TYPE_START, atts );
+            sink.text( " + " );
+            sink.unknown( "span", TAG_TYPE_END, null );
+
+            atts = new SinkEventAttributeSet();
+            atts.addAttribute( SinkEventAttributes.STYLE, "display:none;" );
+            atts.addAttribute( SinkEventAttributes.ID, toHtmlId( testCase.getFullName() ) + "on" );
+            sink.unknown( "span", TAG_TYPE_START, atts );
+            sink.text( " - " );
+            sink.unknown( "span", TAG_TYPE_END, null );
+
+            sink.text( "[ Detail ]" );
+            sink.link_();
+
+            sink.unknown( "div", TAG_TYPE_END, null );
+
+            sink.tableCell_();
+        }
+        else
+        {
+            sinkCellAnchor( sink, testCase.getName(), "TC_" + toHtmlId( testCase.getFullName() ) );
+        }
+
+        sinkCell( sink, numberFormat.format( testCase.getTime() ) );
+
+        sink.tableRow_();
+
+        if ( testCase.hasFailure() )
+        {
+            sink.tableRow();
+
+            sinkCell( sink, "" );
+            sinkCell( sink, testCase.getFailureMessage() );
+            sinkCell( sink, "" );
+            sink.tableRow_();
+
+            String detail = testCase.getFailureDetail();
+            if ( detail != null )
+            {
+                sink.tableRow();
+                sinkCell( sink, "" );
+
+                sink.tableCell();
+                SinkEventAttributeSet atts = new SinkEventAttributeSet();
+                atts.addAttribute( SinkEventAttributes.ID, toHtmlId( testCase.getFullName() ) + "error" );
+                atts.addAttribute( SinkEventAttributes.STYLE, "display:none;" );
+                sink.unknown( "div", TAG_TYPE_START, atts );
+
+                sink.verbatim( null );
+                sink.text( detail );
+                sink.verbatim_();
+
+                sink.unknown( "div", TAG_TYPE_END, null );
+                sink.tableCell_();
+
+                sinkCell( sink, "" );
+
+                sink.tableRow_();
+            }
+        }
+    }
 
     private String toHtmlId( String id )
     {
-        return id.replace( ".", "_" );
+        return DoxiaUtils.isValidId( id ) ? id : DoxiaUtils.encodeId( id, true );
     }
 
-    private void constructFailureDetails( Sink sink, ResourceBundle bundle, List<ReportTestCase> failureList )
+    private void constructFailureDetails( Sink sink, ResourceBundle bundle, List<ReportTestCase> failures )
     {
-        Iterator<ReportTestCase> failIter = failureList.iterator();
+        sink.section1();
+        sink.sectionTitle1();
+        sink.text( bundle.getString( "report.surefire.label.failuredetails" ) );
+        sink.sectionTitle1_();
 
-        if ( failIter != null )
+        sinkAnchor( sink, "Failure_Details" );
+
+        constructHotLinks( sink, bundle );
+
+        sinkLineBreak( sink );
+
+        sink.table();
+
+        sink.tableRows( new int[]{ LEFT, LEFT }, true );
+
+        for ( ReportTestCase tCase : failures )
         {
-            sink.section1();
-            sink.sectionTitle1();
-            sink.text( bundle.getString( "report.surefire.label.failuredetails" ) );
-            sink.sectionTitle1_();
+            sink.tableRow();
 
-            sinkAnchor( sink, "Failure_Details" );
+            sink.tableCell();
 
-            constructHotLinks( sink, bundle );
+            String type = tCase.getFailureType();
 
-            sinkLineBreak( sink );
+            sinkIcon( type, sink );
 
-            sink.table();
+            sink.tableCell_();
 
-            sink.tableRows( new int[]{ LEFT, LEFT }, true );
+            sinkCellAnchor( sink, tCase.getName(), toHtmlId( tCase.getFullName() ) );
 
-            while ( failIter.hasNext() )
+            sink.tableRow_();
+
+            String message = tCase.getFailureMessage();
+
+            sink.tableRow();
+
+            sinkCell( sink, "" );
+
+            sinkCell( sink, message == null ? type : type + ": " + message );
+
+            sink.tableRow_();
+
+            String detail = tCase.getFailureDetail();
+            if ( detail != null )
             {
-                ReportTestCase tCase = failIter.next();
-
-                Map<String, Object> failure = tCase.getFailure();
-
-                sink.tableRow();
-
-                sink.tableCell();
-
-                String type = (String) failure.get( "type" );
-                sinkIcon( type, sink );
-
-                sink.tableCell_();
-
-                sinkCellAnchor( sink, tCase.getName(), tCase.getFullName() );
-
-                sink.tableRow_();
-
-                String message = (String) failure.get( "message" );
-
                 sink.tableRow();
 
                 sinkCell( sink, "" );
 
-                StringBuilder sb = new StringBuilder();
-                sb.append( type );
+                sink.tableCell();
+                SinkEventAttributeSet atts = new SinkEventAttributeSet();
+                atts.addAttribute( SinkEventAttributes.ID, tCase.getName() + "error" );
+                sink.unknown( "div", TAG_TYPE_START, atts );
 
-                if ( message != null )
+                String fullClassName = tCase.getFullClassName();
+                String errorLineNumber = tCase.getFailureErrorLine();
+                if ( xrefLocation != null )
                 {
-                    sb.append( ": " );
-                    sb.append( message );
+                    String path = fullClassName.replace( '.', '/' );
+                    sink.link( xrefLocation + "/" + path + ".html#" + errorLineNumber );
                 }
+                sink.text( fullClassName + ":" + errorLineNumber );
 
-                sinkCell( sink, sb.toString() );
+                if ( xrefLocation != null )
+                {
+                    sink.link_();
+                }
+                sink.unknown( "div", TAG_TYPE_END, null );
+
+                sink.tableCell_();
 
                 sink.tableRow_();
-
-                List<String> detail = (List<String>) failure.get( "detail" );
-                if ( detail != null )
-                {
-                    boolean firstLine = true;
-
-                    String techMessage = "";
-                    for ( String line : detail )
-                    {
-                        techMessage = line;
-                        if ( firstLine )
-                        {
-                            firstLine = false;
-                        }
-                        else
-                        {
-                            sink.text( "    " );
-                        }
-                    }
-
-                    sink.tableRow();
-
-                    sinkCell( sink, "" );
-
-                    sink.tableCell();
-                    SinkEventAttributeSet atts = new SinkEventAttributeSet();
-                    atts.addAttribute( SinkEventAttributes.ID, tCase.getName() + "error" );
-                    sink.unknown( "div", new Object[]{ HtmlMarkup.TAG_TYPE_START }, atts );
-
-                    if ( xrefLocation != null )
-                    {
-                        String path = tCase.getFullClassName().replace( '.', '/' );
-
-                        sink.link( xrefLocation + "/" + path + ".html#" +
-                                       getErrorLineNumber( tCase.getFullName(), techMessage ) );
-                    }
-                    sink.text(
-                        tCase.getFullClassName() + ":" + getErrorLineNumber( tCase.getFullName(), techMessage ) );
-
-                    if ( xrefLocation != null )
-                    {
-                        sink.link_();
-                    }
-                    sink.unknown( "div", new Object[]{ HtmlMarkup.TAG_TYPE_END }, null );
-
-                    sink.tableCell_();
-
-                    sink.tableRow_();
-                }
             }
-
-            sink.tableRows_();
-
-            sink.table_();
         }
 
+        sink.tableRows_();
+
+        sink.table_();
+
         sinkLineBreak( sink );
 
         sink.section1_();
     }
 
-    private String getErrorLineNumber( String className, String source )
-    {
-        StringTokenizer tokenizer = new StringTokenizer( source );
-
-        String lineNo = "";
-
-        while ( tokenizer.hasMoreTokens() )
-        {
-            String token = tokenizer.nextToken();
-            if ( token.startsWith( className ) )
-            {
-                int idx = token.indexOf( ":" );
-                lineNo = token.substring( idx + 1, token.indexOf( ")" ) );
-                break;
-            }
-        }
-        return lineNo;
-    }
-
     private void constructHotLinks( Sink sink, ResourceBundle bundle )
     {
         if ( !testSuites.isEmpty() )
@@ -772,28 +724,24 @@ public class SurefireReportGenerator
 
     private static String javascriptToggleDisplayCode()
     {
-        final StringBuilder str = new StringBuilder( 64 );
 
         // the javascript code is emitted within a commented CDATA section
         // so we have to start with a newline and comment the CDATA closing in the end
-        str.append( "\n" );
-        str.append( "function toggleDisplay(elementId) {\n" );
-        str.append( " var elm = document.getElementById(elementId + 'error');\n" );
-        str.append( " if (elm && typeof elm.style != \"undefined\") {\n" );
-        str.append( " if (elm.style.display == \"none\") {\n" );
-        str.append( " elm.style.display = \"\";\n" );
-        str.append( " document.getElementById(elementId + 'off').style.display = \"none\";\n" );
-        str.append( " document.getElementById(elementId + 'on').style.display = \"inline\";\n" );
-        str.append( " }" );
-        str.append( " else if (elm.style.display == \"\") {" );
-        str.append( " elm.style.display = \"none\";\n" );
-        str.append( " document.getElementById(elementId + 'off').style.display = \"inline\";\n" );
-        str.append( " document.getElementById(elementId + 'on').style.display = \"none\";\n" );
-        str.append( " } \n" );
-        str.append( " } \n" );
-        str.append( " }\n" );
-        str.append( "//" );
 
-        return str.toString();
+        return "\n" + "function toggleDisplay(elementId) {\n"
+                + " var elm = document.getElementById(elementId + 'error');\n"
+                + " if (elm && typeof elm.style != \"undefined\") {\n"
+                + " if (elm.style.display == \"none\") {\n"
+                + " elm.style.display = \"\";\n"
+                + " document.getElementById(elementId + 'off').style.display = \"none\";\n"
+                + " document.getElementById(elementId + 'on').style.display = \"inline\";\n"
+                + " }" + " else if (elm.style.display == \"\") {"
+                + " elm.style.display = \"none\";\n"
+                + " document.getElementById(elementId + 'off').style.display = \"inline\";\n"
+                + " document.getElementById(elementId + 'on').style.display = \"none\";\n"
+                + " } \n"
+                + " } \n"
+                + " }\n"
+                + "//";
     }
 }
