@@ -20,7 +20,7 @@ package org.apache.maven.surefire.util;
  */
 
 import java.util.List;
-import java.util.Properties;
+import java.util.Map;
 
 /**
  * @author Kristian Rosenvold
@@ -33,7 +33,7 @@ public interface ScanResult
 
     TestsToRun applyFilter( ScannerFilter scannerFilter, ClassLoader testClassLoader );
 
-    List getClassesSkippedByValidation( ScannerFilter scannerFilter, ClassLoader testClassLoader );
+    List<Class<?>> getClassesSkippedByValidation( ScannerFilter scannerFilter, ClassLoader testClassLoader );
 
-    void writeTo( Properties properties );
+    void writeTo( Map<String, String> properties );
 }
