@@ -1,4 +1,5 @@
 package org.apache.maven.surefire.booter;
+
 /*
  * Licensed to the Apache Software Foundation (ASF) under one
  * or more contributor license agreements.  See the NOTICE file
@@ -25,5 +26,5 @@ import java.util.Map;
  */
 public interface KeyValueSource
 {
-    void copyTo( Map target );
+    void copyTo( Map<Object, Object> target );
 }
