@@ -39,7 +39,6 @@ import static junit.framework.Assert.assertTrue;
  */
 public class TestFile
 {
-
     private final File file;
 
     private final Charset encoding;
@@ -148,4 +147,9 @@ public class TestFile
     {
         return file.toURI();
     }
+
+    public File getFile()
+    {
+        return file;
+    }
 }
