@@ -46,8 +46,9 @@ public class JUnit4RunListener
     protected final RunListener reporter;
 
     /**
-     * This flag is set after a failure has occurred so that a <code>testSucceeded</code> event is not fired.
-     * This is necessary because JUnit4 always fires a <code>testRunFinished</code> event-- even if there was a failure.
+     * This flag is set after a failure has occurred so that a {@link RunListener#testSucceeded} event is not fired.
+     * This is necessary because JUnit4 always fires a {@link org.junit.runner.notification.RunListener#testRunFinished}
+     * event-- even if there was a failure.
      */
     private final ThreadLocal<Boolean> failureFlag = new InheritableThreadLocal<Boolean>();
 
@@ -68,6 +69,7 @@ public class JUnit4RunListener
      *
      * @see org.junit.runner.notification.RunListener#testIgnored(org.junit.runner.Description)
      */
+    @Override
     public void testIgnored( Description description )
         throws Exception
     {
@@ -80,11 +82,18 @@ public class JUnit4RunListener
      *
      * @see org.junit.runner.notification.RunListener#testStarted(org.junit.runner.Description)
      */
+    @Override
     public void testStarted( Description description )
         throws Exception
     {
-        reporter.testStarting( createReportEntry( description ) );
-        failureFlag.remove();
+        try
+        {
+            reporter.testStarting( createReportEntry( description ) );
+        }
+        finally
+        {
+            failureFlag.remove();
+        }
     }
 
     /**
@@ -92,38 +101,52 @@ public class JUnit4RunListener
      *
      * @see org.junit.runner.notification.RunListener#testFailure(org.junit.runner.notification.Failure)
      */
+    @Override
     @SuppressWarnings( { "ThrowableResultOfMethodCallIgnored" } )
     public void testFailure( Failure failure )
         throws Exception
     {
-        String testHeader = failure.getTestHeader();
-        if ( isInsaneJunitNullString( testHeader ) )
+        try
         {
-            testHeader = "Failure when constructing test";
+            String testHeader = failure.getTestHeader();
+            if ( isInsaneJunitNullString( testHeader ) )
+            {
+                testHeader = "Failure when constructing test";
+            }
+
+            String testClassName = getClassName( failure.getDescription() );
+            StackTraceWriter stackTrace = createStackTraceWriter( failure );
+
+            ReportEntry report = withException( testClassName, testHeader, stackTrace );
+
+            if ( failure.getException() instanceof AssertionError )
+            {
+                reporter.testFailed( report );
+            }
+            else
+            {
+                reporter.testError( report );
+            }
         }
-
-        ReportEntry report =
-            withException( getClassName( failure.getDescription() ), testHeader, createStackTraceWriter( failure ) );
-
-        if ( failure.getException() instanceof AssertionError )
+        finally
         {
-            reporter.testFailed( report );
+            failureFlag.set( true );
         }
-        else
-        {
-            reporter.testError( report );
-        }
-
-        failureFlag.set( true );
     }
 
     @SuppressWarnings( "UnusedDeclaration" )
     public void testAssumptionFailure( Failure failure )
     {
-        Description desc = failure.getDescription();
-        String test = getClassName( desc );
-        reporter.testAssumptionFailure( assumption( test, desc.getDisplayName(), failure.getMessage() ) );
-        failureFlag.set( true );
+        try
+        {
+            Description desc = failure.getDescription();
+            String test = getClassName( desc );
+            reporter.testAssumptionFailure( assumption( test, desc.getDisplayName(), failure.getMessage() ) );
+        }
+        finally
+        {
+            failureFlag.set( true );
+        }
     }
 
     /**
@@ -131,6 +154,7 @@ public class JUnit4RunListener
      *
      * @see org.junit.runner.notification.RunListener#testFinished(org.junit.runner.Description)
      */
+    @Override
     public void testFinished( Description description )
         throws Exception
     {
