@@ -23,11 +23,17 @@ import org.apache.maven.surefire.common.junit4.JUnit4RunListener;
 import org.apache.maven.surefire.report.ConsoleOutputReceiver;
 import org.apache.maven.surefire.report.RunListener;
 import org.apache.maven.surefire.report.SimpleReportEntry;
+import org.apache.maven.surefire.report.TestSetReportEntry;
 import org.apache.maven.surefire.testset.TestSetFailedException;
 import org.junit.runner.Description;
 import org.junit.runner.Result;
 import org.junit.runner.notification.Failure;
 
+import java.util.Collections;
+import java.util.Map;
+
+import static org.apache.maven.surefire.util.internal.ObjectUtils.systemProps;
+
 /**
  * A class to be used when there is no JUnit parallelism (methods or/and class). This allow to workaround JUnit
  * limitation a la Junit4 provider. Specifically, we can redirect properly the output even if we don't have class
@@ -47,21 +53,33 @@ public class NonConcurrentRunListener
         super( reporter );
     }
 
+    @Override
     public synchronized void writeTestOutput( byte[] buf, int off, int len, boolean stdout )
     {
         // We can write immediately: no parallelism and a single class.
         ( (ConsoleOutputReceiver) reporter ).writeTestOutput( buf, off, len, stdout );
     }
 
+    @Override
     protected SimpleReportEntry createReportEntry( Description description )
     {
         return new SimpleReportEntry( extractDescriptionClassName( description ), description.getDisplayName() );
     }
 
-    protected SimpleReportEntry createReportEntryForTestSet( Description description )
+    private TestSetReportEntry createReportEntryForTestSet( Description description, Map<String, String> systemProps )
     {
         String testClassName = extractDescriptionClassName( description );
-        return new SimpleReportEntry( testClassName, testClassName );
+        return new SimpleReportEntry( testClassName, testClassName, systemProps );
+    }
+
+    private TestSetReportEntry createTestSetReportEntryStarted( Description description )
+    {
+        return createReportEntryForTestSet( description, Collections.<String, String>emptyMap() );
+    }
+
+    private TestSetReportEntry createTestSetReportEntryFinished( Description description )
+    {
+        return createReportEntryForTestSet( description, systemProps() );
     }
 
     @Override
@@ -91,10 +109,11 @@ public class NonConcurrentRunListener
             currentTestSetDescription = description;
             if ( lastFinishedDescription != null )
             {
-                reporter.testSetCompleted( createReportEntryForTestSet( lastFinishedDescription ) );
+                TestSetReportEntry reportEntry = createTestSetReportEntryFinished( lastFinishedDescription );
+                reporter.testSetCompleted( reportEntry );
                 lastFinishedDescription = null;
             }
-            reporter.testSetStarting( createReportEntryForTestSet( description ) );
+            reporter.testSetStarting( createTestSetReportEntryStarted( description ) );
         }
     }
 
@@ -164,7 +183,7 @@ public class NonConcurrentRunListener
     {
         if ( lastFinishedDescription != null )
         {
-            reporter.testSetCompleted( createReportEntryForTestSet( lastFinishedDescription ) );
+            reporter.testSetCompleted( createTestSetReportEntryFinished( lastFinishedDescription ) );
             lastFinishedDescription = null;
         }
     }
