@@ -20,7 +20,8 @@ package org.apache.maven.surefire.junitcore.pc;
  */
 
 import org.apache.maven.surefire.junitcore.JUnitCoreParameters;
-import org.apache.maven.surefire.junitcore.Logger;
+import org.apache.maven.surefire.report.ConsoleStream;
+import org.apache.maven.surefire.report.DefaultDirectConsoleReporter;
 import org.apache.maven.surefire.testset.TestSetFailedException;
 import org.junit.AfterClass;
 import org.junit.BeforeClass;
@@ -58,6 +59,8 @@ import static java.util.concurrent.TimeUnit.MILLISECONDS;
 @RunWith( Theories.class )
 public final class ParallelComputerUtilTest
 {
+    private final ConsoleStream logger = new DefaultDirectConsoleReporter( System.out );
+
     @DataPoint
     public static final int CPU_1 = 1;
 
@@ -84,7 +87,10 @@ public final class ParallelComputerUtilTest
 
     @Before
     public void beforeTest()
+        throws InterruptedException
     {
+        System.gc();
+        Thread.sleep( 50L );
         assertFalse( Thread.currentThread().isInterrupted() );
     }
 
@@ -968,7 +974,7 @@ public final class ParallelComputerUtilTest
         properties.put(PARALLEL_KEY, "methods");
         properties.put(THREADCOUNTMETHODS_KEY, "2");
         JUnitCoreParameters params = new JUnitCoreParameters( properties );
-        ParallelComputerBuilder pcBuilder = new ParallelComputerBuilder( new Logger(), params );
+        ParallelComputerBuilder pcBuilder = new ParallelComputerBuilder( logger, params );
         ParallelComputer pc = pcBuilder.buildComputer();
         Result result = new JUnitCore().run( pc, TestClass.class );
         long timeSpent = stopwatch.runtime( MILLISECONDS );
@@ -992,7 +998,7 @@ public final class ParallelComputerUtilTest
         properties.put(THREADCOUNTMETHODS_KEY, "2");
         properties.put(PARALLEL_TIMEOUT_KEY, Double.toString(2.5d));
         JUnitCoreParameters params = new JUnitCoreParameters( properties );
-        ParallelComputerBuilder pcBuilder = new ParallelComputerBuilder( new Logger(), params );
+        ParallelComputerBuilder pcBuilder = new ParallelComputerBuilder( logger, params );
         ParallelComputer pc = pcBuilder.buildComputer();
         new JUnitCore().run( pc, TestClass.class );
         long timeSpent = stopwatch.runtime( MILLISECONDS );
@@ -1015,7 +1021,7 @@ public final class ParallelComputerUtilTest
         properties.put(THREADCOUNTMETHODS_KEY, "2");
         properties.put(PARALLEL_TIMEOUTFORCED_KEY, Double.toString(2.5d));
         JUnitCoreParameters params = new JUnitCoreParameters( properties );
-        ParallelComputerBuilder pcBuilder = new ParallelComputerBuilder( new Logger(), params );
+        ParallelComputerBuilder pcBuilder = new ParallelComputerBuilder( logger, params );
         ParallelComputer pc = pcBuilder.buildComputer();
         new JUnitCore().run( pc, TestClass.class );
         long timeSpent = stopwatch.runtime( MILLISECONDS );
@@ -1041,7 +1047,7 @@ public final class ParallelComputerUtilTest
         properties.put(PARALLEL_TIMEOUT_KEY, Double.toString(2.5d));
         properties.put(PARALLEL_TIMEOUTFORCED_KEY, Double.toString(3.5d));
         JUnitCoreParameters params = new JUnitCoreParameters( properties );
-        ParallelComputerBuilder pcBuilder = new ParallelComputerBuilder( new Logger(), params );
+        ParallelComputerBuilder pcBuilder = new ParallelComputerBuilder( logger, params );
         ParallelComputer pc = pcBuilder.buildComputer();
         new JUnitCore().run( pc, TestClass.class );
         long timeSpent = stopwatch.runtime( MILLISECONDS );
@@ -1065,7 +1071,7 @@ public final class ParallelComputerUtilTest
         properties.put(PARALLEL_TIMEOUTFORCED_KEY, Double.toString(3.5d));
         properties.put(PARALLEL_TIMEOUT_KEY, Double.toString(4.0d));
         JUnitCoreParameters params = new JUnitCoreParameters( properties );
-        ParallelComputerBuilder pcBuilder = new ParallelComputerBuilder( new Logger(), params );
+        ParallelComputerBuilder pcBuilder = new ParallelComputerBuilder( logger, params );
         ParallelComputer pc = pcBuilder.buildComputer();
         new JUnitCore().run( pc, TestClass.class );
         long timeSpent = stopwatch.runtime( MILLISECONDS );
